@@ -15,7 +15,7 @@ from pkg_resources import get_distribution as _get_distribution
 
 from . import epsilon, linalg, random, special, ma
 from .api import get_include, get_lib
-from ._array import cartesian, is_all_equal, is_all_finite, is_crescent
+from ._array import cartesian, is_all_equal, is_all_finite, is_crescent, unique
 
 try:
     __version__ = _get_distribution('numpy_sugar').version
