@@ -39,7 +39,11 @@ def economic_qs_linear(G):
     Returns:
         tuple: ``((Q0, Q1), S0)``.
     """
-    G = asarray(G, float)
+    import dask.array as da
+
+    if not isinstance(G, da.Array):
+        G = asarray(G, float)
+
     if G.shape[0] > G.shape[1]:
         (Q, Ssq, _) = svd(G, full_matrices=True)
         S0 = Ssq**2
